from setuptools import setup, find_packages

setup(
    name='siddhu',
    version='0.4',  # Incremented version number
    packages=find_packages(),
    install_requires=[],
    description='A simple example library by Siddharth',
    author='Siddharth',
    author_email='siddharth09082001@gmail.com',
    # url='https://github.com/yourusername/siddhu',  # Uncomment if you have a URL
)
